Package: initscripts
Version: 2.86.ds1-1
Severity: wishlist

-------- Original Message --------
Subject: Re:bootlogd status?
Date: Tue, 17 Jan 2006 09:53:04 +0100
From: Joel Soete <[EMAIL PROTECTED]>
To: jdthood <[EMAIL PROTECTED]>
CC: 327865-submitter <[EMAIL PROTECTED]>,  rickfriedman <[EMAIL PROTECTED]>, 
klao <[EMAIL PROTECTED]>,  Greek0 <[EMAIL PROTECTED]>, ed <[EMAIL PROTECTED]>,  
tsg45800 <[EMAIL PROTECTED]>

> With sysvinit 2.86.ds1-10, does bootlogd work for you?
> If so, please report this.
> 
> If not, please report this and provide some information.

May be better subject of another br (don't hesitate to let me now)

On some hppa boxes (namely some D & K class model) the console used are 'ttyB0'
which bootlogd ignore ;-(

> * What error message(s) do you see?

so all boot messages disappear  ;-(

> * When do these error messages appear?

(when I started to boot with bootlogd enable on my d380 model ;-)

> * Do you have /var on a separate filesystem?

Yes

> * Do you have any idea why bootlogd is failing on your system(s)?
> -- 
> Thomas Hood

Sorry, I didn't reach to find better then:
#! /bin/sh /usr/share/dpatch/dpatch-run
# Feel free to add your own comments

@DPATCH@
--- sysvinit-2.86.ds1.orig/src/bootlogd.c
+++ sysvinit-2.86.ds1/src/bootlogd.c
@@ -71,6 +71,7 @@
        char    *dev1;
        char    *dev2;
 } consdev[] = {
+       { "ttyB",       "/dev/ttyB%s",          NULL            },
        { "ttySC",      "/dev/ttySC%s",         "/dev/ttsc/%s"  },
        { "ttyS",       "/dev/ttyS%s",          "/dev/tts/%s"   },
        { "tty",        "/dev/tty%s",           "/dev/vc/%s"    },
@@ -82,7 +83,7 @@
  *     Devices to try as console if not found on kernel command line.
  *     Tried from left to right (as opposed to kernel cmdline).
  */
-char *defcons[] = { "tty0", "hvc0", "ttyS0", "ttySC0", NULL };
+char *defcons[] = { "tty0", "hvc0", "ttyS0", "ttySC0", "ttyB0", NULL };

 /*
  *     Catch signals.
@@ -270,7 +271,7 @@
         *      OK, so find console= in /proc/cmdline.
         *      Parse in reverse, opening as we go.
         *
         *      Valid console devices: ttySC, ttyS, tty, hvc.
         */
        p = buf + n;
        *p-- = 0;
@@ -270,7 +271,7 @@
         *      Parse in reverse, opening as we go.
         *
-        *      Valid console devices: ttySC, ttyS, tty, hvc.
+        *      Valid console devices: ttyB, ttySC, ttyS, tty, hvc.
         */
        p = buf + n;
====<>====

Thanks again,
    Joel



-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of "unsubscribe". Trouble? Contact [EMAIL PROTECTED]

Reply via email to